;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "buffer-manage" "20241019.1748"
  "Manage buffers."
  '((emacs          "26.1")
    (choice-program "0.13")
    (dash           "2.17.0"))
  :url "https://github.com/plandes/buffer-manage"
  :commit "3d338b1e64f256ccb70adf81de4c04bcda7eb8d8"
  :revdesc "3d338b1e64f2"
  :keywords '("internal" "maint"))
